pub fn artifact<'a>(
programs: &'a [CompiledProgram],
entry: &str,
digest: u64,
) -> Option<&'a [u8]>Expand description
The artifact holding entry, if one was compiled from source matching
digest. A mismatch is a stale artifact and reads as absent.