StoryOp

Struct StoryOp 

pub struct StoryOp {
    pub name: String,
    pub value: i32,
    pub add: bool,
}
One variable operation in a Story’s script. All story state is named integer variables, starting at 0 each playthrough: a plain flag is a variable set to 1 and cleared to 0.

Fields

name: String

The variable name.

value: i32

The value assigned (or added).

add: bool

false assigns value; true adds it to the current value.