pub fn run(ctx: &mut PipelineContext<'_>) -> Result<(), CnResult>Expand description
Complete world’s content with the engine defaults it does not opt out of.
Errors when the world declares more than one EngineDefaults (which one
applies would be arbitrary), or when baking an injected payload fails.